summaryrefslogtreecommitdiffstats
path: root/lib/store/KoXmlWriter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/store/KoXmlWriter.cpp')
-rw-r--r--lib/store/KoXmlWriter.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/lib/store/KoXmlWriter.cpp b/lib/store/KoXmlWriter.cpp
index dca95d8a..f3568606 100644
--- a/lib/store/KoXmlWriter.cpp
+++ b/lib/store/KoXmlWriter.cpp
@@ -72,31 +72,31 @@ void KoXmlWriter::endDocument()
Q_ASSERT( m_tags.isEmpty() );
}
// returns the value of indentInside of the tqparent
bool KoXmlWriter::prepareForChild()
{
if ( !m_tags.isEmpty() ) {
- Tag& tqparent = m_tags.top();
- if ( !tqparent.hasChildren ) {
- closeStartElement( tqparent );
- tqparent.hasChildren = true;
- tqparent.lastChildIsText = false;
+ Tag& parent = m_tags.top();
+ if ( !parent.hasChildren ) {
+ closeStartElement( parent );
+ parent.hasChildren = true;
+ parent.lastChildIsText = false;
}
- if ( tqparent.indentInside ) {
+ if ( parent.indentInside ) {
writeIndent();
}
- return tqparent.indentInside;
+ return parent.indentInside;
}
return true;
}
void KoXmlWriter::prepareForTextNode()
{
- Tag& tqparent = m_tags.top();
- if ( !tqparent.hasChildren ) {
- closeStartElement( tqparent );
- tqparent.hasChildren = true;
- tqparent.lastChildIsText = true;
+ Tag& parent = m_tags.top();
+ if ( !parent.hasChildren ) {
+ closeStartElement( parent );
+ parent.hasChildren = true;
+ parent.lastChildIsText = true;
}
}
@@ -104,7 +104,7 @@ void KoXmlWriter::startElement( const char* tagName, bool indentInside )
{
Q_ASSERT( tagName != 0 );
// Tell tqparent that it has tqchildren
bool parentIndent = prepareForChild();
m_tags.push( Tag( tagName, parentIndent && indentInside ) );
@@ -72,31 +72,31 @@ void KoXmlWriter::endDocument()
Q_ASSERT( m_tags.isEmpty() );
}
-// returns the value of indentInside of the tqparent
+// returns the value of indentInside of the parent
bool KoXmlWriter::prepareForChild()
{
@@ -104,7 +104,7 @@ void KoXmlWriter::startElement( const char* tagName, bool indentInside )
{
Q_ASSERT( tagName != 0 );
- // Tell tqparent that it has tqchildren
+ // Tell parent that it has tqchildren
bool parentIndent = prepareForChild();
m_tags.push( Tag( tagName, parentIndent && indentInside ) );